==> apache-airflow-2.0.1rc1.tar.gz: apache-airflow-2.0.1rc1/airflow/contrib/hooks/gcp_sql_hook.py <==
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""This module is deprecated. Please use `airflow.providers.google.cloud.hooks.cloud_sql`."""

import warnings

from airflow.providers.google.cloud.hooks.cloud_sql import CloudSQLDatabaseHook, CloudSQLHook

warnings.warn(
    "This module is deprecated. Please use `airflow.providers.google.cloud.hooks.cloud_sql`",
    DeprecationWarning,
    stacklevel=2,
)


class CloudSqlDatabaseHook(CloudSQLDatabaseHook):
    """
    This class is deprecated.
    Please use `airflow.providers.google.cloud.hooks.cloud_sql.CloudSQLDatabaseHook`.
    """

    def __init__(self, *args, **kwargs):
        warnings.warn(self.__doc__, DeprecationWarning, stacklevel=2)
        super().__init__(*args, **kwargs)


class CloudSqlHook(CloudSQLHook):
    """This class is deprecated. Please use `airflow.providers.google.cloud.hooks.sql.CloudSQLHook`."""

    def __init__(self, *args, **kwargs):
        warnings.warn(self.__doc__, DeprecationWarning, stacklevel=2)
        super().__init__(*args, **kwargs)

==> apache-airflow-2.2.0rc1.tar.gz: apache-airflow-2.2.0rc1/airflow/contrib/hooks/gcp_sql_hook.py <==
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""This module is deprecated. Please use :mod:`airflow.providers.google.cloud.hooks.cloud_sql`."""

import warnings

from airflow.providers.google.cloud.hooks.cloud_sql import CloudSQLDatabaseHook, CloudSQLHook

warnings.warn(
    "This module is deprecated. Please use `airflow.providers.google.cloud.hooks.cloud_sql`",
    DeprecationWarning,
    stacklevel=2,
)


class CloudSqlDatabaseHook(CloudSQLDatabaseHook):
    """
    This class is deprecated.
    Please use `airflow.providers.google.cloud.hooks.cloud_sql.CloudSQLDatabaseHook`.
    """

    def __init__(self, *args, **kwargs):
        warnings.warn(self.__doc__, DeprecationWarning, stacklevel=2)
        super().__init__(*args, **kwargs)


class CloudSqlHook(CloudSQLHook):
    """This class is deprecated. Please use `airflow.providers.google.cloud.hooks.sql.CloudSQLHook`."""

    def __init__(self, *args, **kwargs):
        warnings.warn(self.__doc__, DeprecationWarning, stacklevel=2)
        super().__init__(*args, **kwargs)
